Pure helper functions for payment provider logic — no I/O, no side effects.
Pure helper functions for payment provider logic — no I/O, no side effects.
(cents->euro cents)Convert integer cents to a euro amount string (e.g. 11900 -> "119.00"). Always uses a period as decimal separator regardless of JVM locale.
Convert integer cents to a euro amount string (e.g. 11900 -> "119.00"). Always uses a period as decimal separator regardless of JVM locale.
(mollie-status->event-type status)Map a Mollie payment status string to an internal event-type keyword.
Map a Mollie payment status string to an internal event-type keyword.
(mollie-status->payment-status status)Map a Mollie payment status string to a PaymentStatusResult :status keyword. Returns :pending for unrecognised statuses (e.g. "open", "expired").
Map a Mollie payment status string to a PaymentStatusResult :status keyword. Returns :pending for unrecognised statuses (e.g. "open", "expired").
(normalize-event-type raw-type provider)Map provider-specific event strings to internal event-type keywords.
Map provider-specific event strings to internal event-type keywords.
(stripe-event->event-type event-type)Map a Stripe event type string to an internal event-type keyword.
Map a Stripe event type string to an internal event-type keyword.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |